@@ -1,6 +1,6 @@
 package Test::Spelling::Stopwords;
 
-$Test::Spelling::Stopwords::VERSION   = '0.01';
+$Test::Spelling::Stopwords::VERSION   = '0.02';
 $Test::Spelling::Stopwords::AUTHORITY = 'cpan:MANWAR';
 
 use strict;
@@ -27,11 +27,11 @@ Test::Spelling::Stopwords - POD spell-checking with project-specific stopwords
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
-Minimal — just drop this into your F<xt/> directory:
+Minimal - just drop this into your F<xt/> directory:
 
     # xt/spell-pod.t
     use Test::More;
@@ -80,7 +80,7 @@ L<Pod::Wordlist>.
 =head2 How it differs from L<Test::Spelling>
 
 L<Test::Spelling> is the established CPAN module for POD spell-checking.
-C<Test::Spelling::Stopwords> does not replace it — it complements it by
+C<Test::Spelling::Stopwords> does not replace it - it complements it by
 addressing two specific gaps:
 
 =over 4
@@ -109,7 +109,7 @@ The module merges two sources of known words before checking any file:
 
 =over 4
 
-=item Layer 1 — L<Pod::Wordlist>
+=item Layer 1 - L<Pod::Wordlist>
 
 The CPAN-maintained vocabulary of common Perl and technical terms (C<ok>,
 C<undef>, C<dbi>, C<CPAN>, C<accessor>, C<mutators>, etc.). This mirrors
@@ -117,10 +117,10 @@ what C<gen-stopwords> filters out when building F<.stopwords>, so the
 module and the generator always agree on what counts as a known word.
 
 Without this layer the test is stricter than the generator and flags words
-that L<Pod::Wordlist> covers — causing false failures even on a freshly
+that L<Pod::Wordlist> covers - causing false failures even on a freshly
 generated F<.stopwords>.
 
-=item Layer 2 — F<.stopwords>
+=item Layer 2 - F<.stopwords>
 
 Project-specific vocabulary generated by C<gen-stopwords>. Contains only
 terms not already covered by L<Pod::Wordlist>.
@@ -153,7 +153,7 @@ is newer, it emits a C<diag> warning:
     # Run gen-stopwords to regenerate it.
     # ------------------------------------------------------------
 
-This is advisory only — the test continues to run.
+This is advisory only - the test continues to run.
 
 =head2 POD cleaning
 
